pub struct DetectKeycard {
pub timeout: Duration,
}Fields
timeout: DurationTrait Implementations
Sourceimpl Archive for DetectKeycardwhere
Duration: Archive,
impl Archive for DetectKeycardwhere
Duration: Archive,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self>
const COPY_OPTIMIZATION: CopyOptimization<Self>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedDetectKeycard
type Archived = ArchivedDetectKeycard
The archived representation of this type. Read more
Sourcetype Resolver = DetectKeycardResolver
type Resolver = DetectKeycardResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourceimpl BlockingArchive for DetectKeycard
impl BlockingArchive for DetectKeycard
Sourceimpl Clone for DetectKeycard
impl Clone for DetectKeycard
Sourcefn clone(&self) -> DetectKeycard
fn clone(&self) -> DetectKeycard
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DetectKeycard
impl Debug for DetectKeycard
Sourceimpl<__D: Fallible + ?Sized> Deserialize<DetectKeycard, __D> for Archived<DetectKeycard>
impl<__D: Fallible + ?Sized> Deserialize<DetectKeycard, __D> for Archived<DetectKeycard>
Sourcefn deserialize(
&self,
deserializer: &mut __D,
) -> Result<DetectKeycard, <__D as Fallible>::Error>
fn deserialize( &self, deserializer: &mut __D, ) -> Result<DetectKeycard, <__D as Fallible>::Error>
Deserializes using the given deserializer
Sourceimpl MessageId for DetectKeycard
impl MessageId for DetectKeycard
Sourceimpl<__S: Fallible + ?Sized> Serialize<__S> for DetectKeycardwhere
Duration: Serialize<__S>,
impl<__S: Fallible + ?Sized> Serialize<__S> for DetectKeycardwhere
Duration: Serialize<__S>,