pub struct FormatKeycard(pub KeycardId);Tuple Fields
0: KeycardIdTrait Implementations
Sourceimpl Archive for FormatKeycardwhere
KeycardId: Archive,
impl Archive for FormatKeycardwhere
KeycardId: Archive,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self>
const COPY_OPTIMIZATION: CopyOptimization<Self>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedFormatKeycard
type Archived = ArchivedFormatKeycard
The archived representation of this type. Read more
Sourcetype Resolver = FormatKeycardResolver
type Resolver = FormatKeycardResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourceimpl BlockingArchive for FormatKeycard
impl BlockingArchive for FormatKeycard
Sourceimpl Clone for FormatKeycard
impl Clone for FormatKeycard
Sourcefn clone(&self) -> FormatKeycard
fn clone(&self) -> FormatKeycard
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for FormatKeycard
impl Debug for FormatKeycard
Sourceimpl<__D: Fallible + ?Sized> Deserialize<FormatKeycard, __D> for Archived<FormatKeycard>
impl<__D: Fallible + ?Sized> Deserialize<FormatKeycard, __D> for Archived<FormatKeycard>
Sourcefn deserialize(
&self,
deserializer: &mut __D,
) -> Result<FormatKeycard, <__D as Fallible>::Error>
fn deserialize( &self, deserializer: &mut __D, ) -> Result<FormatKeycard, <__D as Fallible>::Error>
Deserializes using the given deserializer
Sourceimpl MessageId for FormatKeycard
impl MessageId for FormatKeycard
Sourceimpl<__S: Fallible + ?Sized> Serialize<__S> for FormatKeycardwhere
KeycardId: Serialize<__S>,
impl<__S: Fallible + ?Sized> Serialize<__S> for FormatKeycardwhere
KeycardId: Serialize<__S>,