pub struct IdentifyKeycard;Trait Implementations
Sourceimpl Archive for IdentifyKeycard
impl Archive for IdentifyKeycard
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self>
const COPY_OPTIMIZATION: CopyOptimization<Self>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedIdentifyKeycard
type Archived = ArchivedIdentifyKeycard
The archived representation of this type. Read more
Sourcetype Resolver = IdentifyKeycardResolver
type Resolver = IdentifyKeycardResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourceimpl BlockingArchive for IdentifyKeycard
impl BlockingArchive for IdentifyKeycard
Sourcetype Response = Result<(KeycardId, Option<KeycardIdentifyError>), KeycardError>
type Response = Result<(KeycardId, Option<KeycardIdentifyError>), KeycardError>
response type for this message
Sourceimpl Clone for IdentifyKeycard
impl Clone for IdentifyKeycard
Sourcefn clone(&self) -> IdentifyKeycard
fn clone(&self) -> IdentifyKeycard
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for IdentifyKeycard
impl Debug for IdentifyKeycard
Sourceimpl<__D: Fallible + ?Sized> Deserialize<IdentifyKeycard, __D> for Archived<IdentifyKeycard>
impl<__D: Fallible + ?Sized> Deserialize<IdentifyKeycard, __D> for Archived<IdentifyKeycard>
Sourcefn deserialize(
&self,
deserializer: &mut __D,
) -> Result<IdentifyKeycard, <__D as Fallible>::Error>
fn deserialize( &self, deserializer: &mut __D, ) -> Result<IdentifyKeycard, <__D as Fallible>::Error>
Deserializes using the given deserializer
Sourceimpl MessageId for IdentifyKeycard
impl MessageId for IdentifyKeycard