pub struct KeycardId(pub Vec<u8>);Tuple Fields
0: Vec<u8>Trait Implementations
Sourceimpl Archive for KeycardId
impl Archive for KeycardId
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self>
const COPY_OPTIMIZATION: CopyOptimization<Self>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedKeycardId
type Archived = ArchivedKeycardId
The archived representation of this type. Read more
Sourcetype Resolver = KeycardIdResolver
type Resolver = KeycardIdResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
impl Eq for KeycardId
impl StructuralPartialEq for KeycardId