pub struct LoadShardFromKeycard;Trait Implementations
Sourceimpl Archive for LoadShardFromKeycard
impl Archive for LoadShardFromKeycard
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self>
const COPY_OPTIMIZATION: CopyOptimization<Self>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedLoadShardFromKeycard
type Archived = ArchivedLoadShardFromKeycard
The archived representation of this type. Read more
Sourcetype Resolver = LoadShardFromKeycardResolver
type Resolver = LoadShardFromKeycardResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourceimpl BlockingArchive for LoadShardFromKeycard
impl BlockingArchive for LoadShardFromKeycard
Sourcetype Response = Result<LoadedShard, KeycardError>
type Response = Result<LoadedShard, KeycardError>
response type for this message
Sourceimpl Clone for LoadShardFromKeycard
impl Clone for LoadShardFromKeycard
Sourcefn clone(&self) -> LoadShardFromKeycard
fn clone(&self) -> LoadShardFromKeycard
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for LoadShardFromKeycard
impl Debug for LoadShardFromKeycard
Sourceimpl<__D: Fallible + ?Sized> Deserialize<LoadShardFromKeycard, __D> for Archived<LoadShardFromKeycard>
impl<__D: Fallible + ?Sized> Deserialize<LoadShardFromKeycard, __D> for Archived<LoadShardFromKeycard>
Sourcefn deserialize(
&self,
deserializer: &mut __D,
) -> Result<LoadShardFromKeycard, <__D as Fallible>::Error>
fn deserialize( &self, deserializer: &mut __D, ) -> Result<LoadShardFromKeycard, <__D as Fallible>::Error>
Deserializes using the given deserializer
Sourceimpl MessageId for LoadShardFromKeycard
impl MessageId for LoadShardFromKeycard