pub struct MasterSeedRestored {
pub seed: Seed,
pub different_device_id: bool,
}Fields
seed: Seeddifferent_device_id: boolTrait Implementations
Sourceimpl Archive for MasterSeedRestoredwhere
Seed: Archive,
bool: Archive,
impl Archive for MasterSeedRestoredwhere
Seed: Archive,
bool: Archive,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self>
const COPY_OPTIMIZATION: CopyOptimization<Self>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedMasterSeedRestored
type Archived = ArchivedMasterSeedRestored
The archived representation of this type. Read more
Sourcetype Resolver = MasterSeedRestoredResolver
type Resolver = MasterSeedRestoredResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourceimpl Clone for MasterSeedRestored
impl Clone for MasterSeedRestored
Sourcefn clone(&self) -> MasterSeedRestored
fn clone(&self) -> MasterSeedRestored
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MasterSeedRestored
impl Debug for MasterSeedRestored
Sourceimpl<__D: Fallible + ?Sized> Deserialize<MasterSeedRestored, __D> for Archived<MasterSeedRestored>
impl<__D: Fallible + ?Sized> Deserialize<MasterSeedRestored, __D> for Archived<MasterSeedRestored>
Sourcefn deserialize(
&self,
deserializer: &mut __D,
) -> Result<MasterSeedRestored, <__D as Fallible>::Error>
fn deserialize( &self, deserializer: &mut __D, ) -> Result<MasterSeedRestored, <__D as Fallible>::Error>
Deserializes using the given deserializer
Sourceimpl<__S: Fallible + ?Sized> Serialize<__S> for MasterSeedRestoredwhere
Seed: Serialize<__S>,
bool: Serialize<__S>,
impl<__S: Fallible + ?Sized> Serialize<__S> for MasterSeedRestoredwhere
Seed: Serialize<__S>,
bool: Serialize<__S>,