pub struct PushShard {
pub shard: Shard,
pub accept_different_device_id: bool,
}Fields
shard: Shardaccept_different_device_id: boolTrait Implementations
Sourceimpl Archive for PushShardwhere
Shard: Archive,
bool: Archive,
impl Archive for PushShardwhere
Shard: Archive,
bool: Archive,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self>
const COPY_OPTIMIZATION: CopyOptimization<Self>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedPushShard
type Archived = ArchivedPushShard
The archived representation of this type. Read more
Sourcetype Resolver = PushShardResolver
type Resolver = PushShardResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourceimpl BlockingArchive for PushShard
impl BlockingArchive for PushShard