pub struct StoreShardToKeycard(pub KeycardId);Tuple Fields
0: KeycardIdTrait Implementations
Sourceimpl Archive for StoreShardToKeycardwhere
KeycardId: Archive,
impl Archive for StoreShardToKeycardwhere
KeycardId: Archive,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self>
const COPY_OPTIMIZATION: CopyOptimization<Self>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedStoreShardToKeycard
type Archived = ArchivedStoreShardToKeycard
The archived representation of this type. Read more
Sourcetype Resolver = StoreShardToKeycardResolver
type Resolver = StoreShardToKeycardResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourceimpl Clone for StoreShardToKeycard
impl Clone for StoreShardToKeycard
Sourcefn clone(&self) -> StoreShardToKeycard
fn clone(&self) -> StoreShardToKeycard
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for StoreShardToKeycard
impl Debug for StoreShardToKeycard
Sourceimpl<__D: Fallible + ?Sized> Deserialize<StoreShardToKeycard, __D> for Archived<StoreShardToKeycard>
impl<__D: Fallible + ?Sized> Deserialize<StoreShardToKeycard, __D> for Archived<StoreShardToKeycard>
Sourcefn deserialize(
&self,
deserializer: &mut __D,
) -> Result<StoreShardToKeycard, <__D as Fallible>::Error>
fn deserialize( &self, deserializer: &mut __D, ) -> Result<StoreShardToKeycard, <__D as Fallible>::Error>
Deserializes using the given deserializer
Sourceimpl MessageId for StoreShardToKeycard
impl MessageId for StoreShardToKeycard
Sourceimpl<__S: Fallible + ?Sized> Serialize<__S> for StoreShardToKeycardwhere
KeycardId: Serialize<__S>,
impl<__S: Fallible + ?Sized> Serialize<__S> for StoreShardToKeycardwhere
KeycardId: Serialize<__S>,